######################################################################
#
# File: test/unit/v3/apiver/apiver_deps.py
#
# Copyright 2021 Backblaze Inc. All Rights Reserved.
#
# License https://www.backblaze.com/using_b2_code.html
#
######################################################################
from __future__ import annotations

from b2sdk.v3 import *  # noqa

V = 3
